@@ -1,5 +1,7 @@
+""" APIs Module Init """
 from .base_url import BaseUrl
 from .key import Key
 from .yoonik_api_exception import YoonikApiException
-from .requests import request
+from .http_requests import request
+from .api_result import ApiResult
 from .face_authentication import FaceAuthentication
